@@ -122,76 +122,3 @@ pub type TrustDnsHttpConnector = HttpConnector<TrustDnsResolver>;
 pub fn new_trust_dns_http_connector() -> TrustDnsHttpConnector {
     TrustDnsHttpConnector::new_with_resolver(TrustDnsResolver::new())
 }
-
-#[cfg(test)]
-mod tests {
-    use super::*;
-    use hyper::{Body, Client, Request};
-
-    #[tokio::test]
-    async fn test_lookup_works() {
-        let connector = new_trust_dns_http_connector();
-        let client = Client::builder().build(connector);
-
-        let request = Request::builder()
-            .method("GET")
-            .uri("http://www.google.com/")
-            .body(Body::empty())
-            .unwrap();
-
-        let response = client.request(request).await.unwrap();
-
-        assert_eq!(response.status(), 200);
-    }
-
-    #[cfg(feature = "rustls-webpki")]
-    #[tokio::test]
-    async fn test_rustls_webpki_roots_works() {
-        let connector = new_rustls_webpki_https_connector();
-        let client = Client::builder().build(connector);
-
-        let request = Request::builder()
-            .method("GET")
-            .uri("https://www.google.com/")
-            .body(Body::empty())
-            .unwrap();
-
-        let response = client.request(request).await.unwrap();
-
-        assert_eq!(response.status(), 200);
-    }
-
-    #[cfg(feature = "rustls-native")]
-    #[tokio::test]
-    async fn test_rustls_native_roots_works() {
-        let connector = new_rustls_native_https_connector();
-        let client = Client::builder().build(connector);
-
-        let request = Request::builder()
-            .method("GET")
-            .uri("https://www.google.com/")
-            .body(Body::empty())
-            .unwrap();
-
-        let response = client.request(request).await.unwrap();
-
-        assert_eq!(response.status(), 200);
-    }
-
-    #[cfg(feature = "native-tls")]
-    #[tokio::test]
-    async fn test_native_tls_works() {
-        let connector = new_native_tls_https_connector();
-        let client = Client::builder().build(connector);
-
-        let request = Request::builder()
-            .method("GET")
-            .uri("https://www.google.com/")
-            .body(Body::empty())
-            .unwrap();
-
-        let response = client.request(request).await.unwrap();
-
-        assert_eq!(response.status(), 200);
-    }
-}
